@@ -210,15 +210,13 @@ def get_sdist_file_path_from_filename(sdist):
         sdist_file = sdist.rstrip(".tar.gz")
         with tarfile.open(os.path.join(utils_pypi.CACHE_THIRDPARTY_DIR, sdist)) as file:
             file.extractall(
-                os.path.join(utils_pypi.CACHE_THIRDPARTY_DIR,
-                             "extracted_sdists", sdist_file)
+                os.path.join(utils_pypi.CACHE_THIRDPARTY_DIR, "extracted_sdists", sdist_file)
             )
     elif sdist.endswith(".zip"):
         sdist_file = sdist.rstrip(".zip")
         with ZipFile(os.path.join(utils_pypi.CACHE_THIRDPARTY_DIR, sdist)) as zip:
             zip.extractall(
-                os.path.join(utils_pypi.CACHE_THIRDPARTY_DIR,
-                             "extracted_sdists", sdist_file)
+                os.path.join(utils_pypi.CACHE_THIRDPARTY_DIR, "extracted_sdists", sdist_file)
             )
 
     else:
@@ -361,8 +359,7 @@ class PythonInputProvider(AbstractProvider):
         ignore_errors=False,
     ):
         self.environment = environment
-        self.environment_marker = get_environment_marker_from_environment(
-            self.environment)
+        self.environment_marker = get_environment_marker_from_environment(self.environment)
         self.repos = repos or []
         self.versions_by_package = {}
         self.dependencies_by_purl = {}
@@ -411,11 +408,9 @@ class PythonInputProvider(AbstractProvider):
         versions = []
         for version, package in repo.get_package_versions(name).items():
             python_version = parse_version(
-                get_python_version_from_env_tag(
-                    python_version=self.environment.python_version)
+                get_python_version_from_env_tag(python_version=self.environment.python_version)
             )
-            wheels = list(package.get_supported_wheels(
-                environment=self.environment))
+            wheels = list(package.get_supported_wheels(environment=self.environment))
             valid_wheel_present = False
             pypi_valid_python_version = False
             if wheels:
@@ -464,8 +459,7 @@ class PythonInputProvider(AbstractProvider):
         Return requirements for a package from the simple repositories.
         """
         python_version = parse_version(
-            get_python_version_from_env_tag(
-                python_version=self.environment.python_version)
+            get_python_version_from_env_tag(python_version=self.environment.python_version)
         )
 
         wheels = utils_pypi.download_wheel(
@@ -478,8 +472,7 @@ class PythonInputProvider(AbstractProvider):
 
         if wheels:
             for wheel in wheels:
-                wheel_location = os.path.join(
-                    utils_pypi.CACHE_THIRDPARTY_DIR, wheel)
+                wheel_location = os.path.join(utils_pypi.CACHE_THIRDPARTY_DIR, wheel)
                 requirements = get_requirements_from_distribution(
                     handler=PypiWheelHandler,
                     location=wheel_location,
@@ -571,8 +564,7 @@ class PythonInputProvider(AbstractProvider):
             ):
                 valid_versions.append(parsed_version)
         if not all(version.is_prerelease for version in valid_versions):
-            valid_versions = [
-                version for version in valid_versions if not version.is_prerelease]
+            valid_versions = [version for version in valid_versions if not version.is_prerelease]
         for version in valid_versions:
             yield Candidate(name=name, version=version, extras=extras)
 
@@ -593,8 +585,7 @@ class PythonInputProvider(AbstractProvider):
             versions.extend(self.get_versions_for_package(name=name))
         else:
             for repo in self.repos:
-                versions.extend(
-                    self.get_versions_for_package(name=name, repo=repo))
+                versions.extend(self.get_versions_for_package(name=name, repo=repo))
 
         if not versions:
             if self.ignore_errors:
@@ -685,8 +676,7 @@ def dfs(mapping: Dict, graph: DirectedGraph, src: str):
 
     return dict(
         package=str(src_purl),
-        dependencies=sorted([dfs(mapping, graph, c)
-                            for c in children], key=lambda d: d["package"]),
+        dependencies=sorted([dfs(mapping, graph, c) for c in children], key=lambda d: d["package"]),
     )
 
 
@@ -804,8 +794,7 @@ def get_setup_requirements(sdist_location: str, setup_py_location: str, setup_cf
     """
 
     if not os.path.exists(setup_py_location) and not os.path.exists(setup_cfg_location):
-        raise Exception(
-            f"No setup.py or setup.cfg found in pypi sdist {sdist_location}")
+        raise Exception(f"No setup.py or setup.cfg found in pypi sdist {sdist_location}")
 
     # Some commonon packages like flask may have some dependencies in setup.cfg
     # and some dependencies in setup.py. We are going to check both.
